import Vue from 'vue'
import VueRouter from 'vue-router'
import NProgress from 'nprogress' // progress bar
import 'nprogress/nprogress.css'
import store from './store'
import { pages } from './views'

Vue.use(VueRouter)

const routes = [
  {
    path: '/',
    name: 'index',
    redirect: '/dashboard',
    component: () => import('@/layout/index.vue'),
    children: [
      ...pages,
    ]
  },
  {
    path: '/login',
    name: 'login',
    component: () => import('@/views/Login.vue')
  },
  {
    path: '/exception',
    name: 'exception',
    component: () => import('@/layout/index.vue'),
    children: [
      {
        path: '404',
        name: 'notfound',
        component: () => import('@/views/NotFound.vue'),
      },
      {
        path: 'norights',
        name: 'norights',
        component: () => import('@/views/NoRights.vue'),
      },
    ]
  },
]

const router = new VueRouter({ routes })

// 校验用户权限
router.beforeEach((to, from, next) => {
  NProgress.start()

  const toLogin = { name: 'login', query: { from: to.name } }
  const toIndex = { name: 'index' }
  const to403 = { name: 'norights' }
  
  // 白名单, 异常页不处理
  if (to.fullPath.indexOf('/exception') > -1) {
    next()
    return
  }

  store.dispatch('checkLogin').then(() => {
  
    // 校验权限
    checkRigths(to).then(() => {
      return to.name === 'login' ? next(toIndex) : next()
    }).catch(() => {
      next(to403)
    })

  }).catch((err) => {
    window.console.error(err.message || err)
    return to.name === 'login' ? next() : next(toLogin)
  })
})

router.afterEach(() => {
  NProgress.done()
})


function checkRigths(route) {
  return store.dispatch('checkMenuAuthority', route.name)
}

export default router
