import lodash from 'lodash'
import { interact } from '../utils'
import apis from '../config/api'

export default {
  state: {
    app: {
      logo: '',
      name: '荟房科技',
      version: 1.0,
    },
    menus: [],
    user: {},
    userLoged: false,
  },
  mutations: {
    updateUser(state, user) {
      state.user = {
        ...state.user,
        ...user,
      }
    },
    syncState(state, payload = {}) {
      Object.keys(payload).forEach(k => state[k] = payload[k])
    }
  },
  actions: {
    checkLogin({ state, commit }) {
      return new Promise((resolve, reject) => {
        if (state.userLoged) {
          resolve(state.user)
          return
        }

        const api = lodash.get(apis, 'user.getuser')
        interact(api).then((data) => {
          commit('syncState', { ...data, userLoged: true })
          resolve(data.user)
        }).catch(() => {
          reject('获取人员信息失败')
        })
      })
    },
    checkMenuAuthority({ state }, menuId) {
      const menuAuthority = ((state.menus || []).filter(m => m.menuId === menuId).authority || '').split(',').filter(x => x)
      const userAuthority = (state.user.authority || '').split(',').filter(x => x)
      return menuAuthority.some(x => userAuthority.indexOf(x) > -1) ? Promise.resolve() : Promise.reject()
    },
    login({ commit }, user) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'user.login')
        interact(api, {...user}).then(() => {
          // commit('updateUser', data)
          commit('syncState', { userLoged: true })
          resolve()
        }).catch((err) => {
          reject(err.message || err)
        })
      })
    },
    logout({ commit }) {
      const api = lodash.get(apis, 'user.logout')
      interact(api).then(() => {
        commit('updateUser', {})
        commit('syncState', { userLoged: false })
      })
    }
  }
}
